@@ -1,4 +1,4 @@
-set rcsId {$Id: confint.tcl,v 1.30 1998/10/02 20:19:20 jfontain Exp $}
+set rcsId {$Id: confint.tcl,v 1.31 1998/11/14 20:05:37 jfontain Exp $}
 
 # minimalist composite widget configuration interface for widget testing and HTML live documentation with configuration applet
 
@@ -11,17 +11,19 @@ proc configurationInterface::configurationInterface {this parentPath args} compo
     composite::manage $this\
         [new listbox $composite::($this,top,path) -font {Helvetica -11 bold} -height 0 -selectmode single] names\
         [new frame $composite::($this,top,path) -background white -highlightbackground black -highlightthickness 1] container
-    new widgetTip -path $composite::($this,names,path) -text {select component(class)}
+    lappend composite::($this,tips) [new widgetTip -path $composite::($this,names,path) -text {select component(class)}]
     pack $composite::($this,names,path) -padx 2 -pady 2 -side left -anchor nw
     pack $composite::($this,container,path) -padx 2 -pady 2 -fill both -expand 1
     composite::manage $this [new scroller $parentPath -height 100] scroller
     pack $composite::($this,scroller,path) -pady 2 -fill both -expand 1
-    new widgetTip -path $composite::($this,scroller,path) -text {enter component options}
+    lappend composite::($this,tips) [new widgetTip -path $composite::($this,scroller,path) -text {enter component options}]
 
     composite::complete $this
 }
 
-proc configurationInterface::~configurationInterface {this} {}
+proc configurationInterface::~configurationInterface {this} {
+    eval delete $composite::($this,tips)
+}
 
 proc configurationInterface::options {this} {}
 
