@@ -1,11 +1,11 @@
-if {[catch {package require stooop 3.6.1}]} {                                             ;# in case stooop package is not installed
+if {[catch {package require stooop 3.7}]} {                                               ;# in case stooop package is not installed
     source stooop.tcl
 }
 namespace import stooop::*
 if {[catch {package require switched 1.4}]} {                                           ;# in case switched package is not installed
     source switched.tcl
 }
-if {[catch {package require scwoop 2.3}]} {                                               ;# in case scwoop package is not installed
+if {[catch {package require scwoop 2.6}]} {                                               ;# in case scwoop package is not installed
     source scwoop.tcl
     source scwoutil.tcl
     source arrowbut.tcl
