@@ -2,7 +2,7 @@
 # the next line restarts using the interpreter \
 exec tclsh "$0" "$@"
 
-# $Id: instapkg.tcl,v 1.6 1998/10/01 21:18:05 jfontain Exp $
+# $Id: instapkg.tcl,v 1.7 1998/11/14 20:15:29 jfontain Exp $
 
 if {[llength $argv]!=1} {
     puts stderr "usage: $argv0 directory"
@@ -22,7 +22,7 @@ if {![file exists $directory]} {
     exit 1
 }
 
-if {[catch {package require stooop 3.6.1} message]} {
+if {[catch {package require stooop 3.7} message]} {
     puts stderr "stooop package must be installed first: $message"
     exit 1
 }
