@@ -1,4 +1,4 @@
-set rcsId {$Id: spinent.tcl,v 1.37 1997/11/02 14:08:30 jfontain Exp $}
+set rcsId {$Id: spinent.tcl,v 1.38 1998/10/01 20:07:02 jfontain Exp $}
 
 class spinEntry {}
 
@@ -133,10 +133,7 @@ proc spinEntry::next {this direction} {
         if {[catch {expr {$value+0}}]} {                                 ;# if entry is editable, contents may not be a valid number
             return [expr {$direction<0?$minimum:$maximum}]
         } else {
-            # first convert current ratio to string in order to avoid internal floating point precision problems
-            # (2.999999... instead of 3.0 for example)
-            ::set value [string range [expr {double($value-$minimum)/$increment}] 0 end]
-            ::set value [expr {(int($value)+$direction)*$increment}]
+            ::set value [expr {$value+($direction*$increment)}]
             if {$value<=$minimum} {
                 return $minimum
             } elseif {$value>=$maximum} {
